namespace :db do
  desc "Create a new PE console user"
  task :create_user => :connect do
    usage_string = 'Usage: rake db:create_user USERNAME="foo@bar.com" PASSWORD="123@#$%^&*()-_+=,?[}{]abc" ROLE="Read-Only|Read-Write|Admin"'
    username = ENV['USERNAME']
    password = ENV['PASSWORD']
    role = Role.find_by_name(ENV['ROLE'])
    if username.nil?
      puts "Missing USERNAME parameter."
      puts usage_string
    elsif password.nil?
      puts "Missing PASSWORD parameter."
      puts usage_string
    elsif role.nil?
      puts "Missing or invalid ROLE parameter."
      puts usage_string
    else
      # If the user exists already we want to reset all of the information about that user:
      #    - password
      #    - role
      #    - status
      #
      # --jeffweiss 11 Sept 2012 
      
      user = nil
      authorized_user = nil
      begin
        user = User.find_by_username username
        authorized_user = AuthorizedUser.find_by_username username
      rescue
        # I don't really care if anything goes wrong, we'll just create the new user
      end

      # if we didn't find one before, create a new one
      user ||= User.new
      user.username = username
        
      user.password = if password.length >= 2 and password.start_with? "'" and password.end_with? "'"
                         password[1..-2]
                       else
                         password
                       end
      user.save!
      
      # if we didn't find an existing one, let's create a new one
      authorized_user ||= AuthorizedUser.new
      authorized_user.username = username
      authorized_user.roles = [role]
      authorized_user.status = "enabled"
      authorized_user.save!        
    end
  end
end
