module ComplianceHelper
  def dashed_zeros(n)
    n != 0 ? n : '–'
  end

  def extract_type_title( resource )
    return [] unless resource
    resource.sub( /\[/, '[<strong>' ).sub( /\]$/, '</strong>]' )
    return resource.match( /^(\w+)\[(.*)\]$/ );
  end

  def emphasize_resource_title( resource )
    return unless resource
    resource.sub( /\[/, '[<strong>' ).sub( /\]$/, '</strong>]' )
  end

  def action_class( outcome )
    outcome.nil? ? 'no-action' : ( outcome ? 'accepted' : 'rejected' )
  end

  def display_nicely( file_data, options = nil )
    return '&mdash;' if file_data == '' or !file_data

    if options
      if options[ :resource_title ]
        file_title = options[ :resource_title ]
      elsif options[ :resource ]
        file_title = extract_type_title( options[ :resource ])[ 2 ]
      end
    end

    if file_data.to_s.match(/^\{md5\}[a-fA-F0-9]{32}$/)
      render 'shared/file_contents', {
        :file_data  => file_data,
        :md5        => file_data.sub( /^\{md5\}/, '' ),
        :file_title => file_title
      }
    elsif file_data.kind_of?(Array) and not file_data.empty?
      "<div>[#{h file_data.join(', ')}]</div>"
    else
      "<div>#{h file_data}</div>"
    end
  end
end
